@@ -12,7 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-
 # alias because we already had an option named argparse
 import argparse as argparse_mod
 import collections
@@ -22,11 +21,12 @@ import json
 import os
 import re
 import sys
+import typing as ty
 import warnings
 
-import appdirs
 from keystoneauth1 import adapter
 from keystoneauth1 import loading
+import platformdirs
 import yaml
 
 from openstack import _log
@@ -35,10 +35,13 @@ from openstack.config import cloud_region
 from openstack.config import defaults
 from openstack.config import vendors
 from openstack import exceptions
+from openstack import warnings as os_warnings
 
-APPDIRS = appdirs.AppDirs('openstack', 'OpenStack', multipath='/etc')
-CONFIG_HOME = APPDIRS.user_config_dir
-CACHE_PATH = APPDIRS.user_cache_dir
+PLATFORMDIRS = platformdirs.PlatformDirs(
+    'openstack', 'OpenStack', multipath='/etc'
+)
+CONFIG_HOME = PLATFORMDIRS.user_config_dir
+CACHE_PATH = PLATFORMDIRS.user_cache_dir
 
 # snaps do set $HOME to something like
 # /home/$USER/snap/openstackclients/$SNAP_VERSION
@@ -46,19 +49,23 @@ CACHE_PATH = APPDIRS.user_cache_dir
 # see https://snapcraft.io/docs/environment-variables
 SNAP_REAL_HOME = os.getenv('SNAP_REAL_HOME')
 if SNAP_REAL_HOME:
-    UNIX_CONFIG_HOME = os.path.join(os.path.join(SNAP_REAL_HOME, '.config'),
-                                    'openstack')
+    UNIX_CONFIG_HOME = os.path.join(
+        os.path.join(SNAP_REAL_HOME, '.config'), 'openstack'
+    )
 else:
     UNIX_CONFIG_HOME = os.path.join(
-        os.path.expanduser(os.path.join('~', '.config')), 'openstack')
+        os.path.expanduser(os.path.join('~', '.config')), 'openstack'
+    )
 UNIX_SITE_CONFIG_HOME = '/etc/openstack'
 
-SITE_CONFIG_HOME = APPDIRS.site_config_dir
+SITE_CONFIG_HOME = PLATFORMDIRS.site_config_dir
 
 CONFIG_SEARCH_PATH = [
     os.getcwd(),
-    CONFIG_HOME, UNIX_CONFIG_HOME,
-    SITE_CONFIG_HOME, UNIX_SITE_CONFIG_HOME
+    CONFIG_HOME,
+    UNIX_CONFIG_HOME,
+    SITE_CONFIG_HOME,
+    UNIX_SITE_CONFIG_HOME,
 ]
 YAML_SUFFIXES = ('.yaml', '.yml')
 JSON_SUFFIXES = ('.json',)
@@ -79,6 +86,7 @@ VENDOR_FILES = [
 ]
 
 BOOL_KEYS = ('insecure', 'cache')
+CSV_KEYS = ('auth_methods',)
 
 FORMAT_EXCLUSIONS = frozenset(['password'])
 
@@ -96,7 +104,7 @@ def get_boolean(value):
 def _auth_update(old_dict, new_dict_source):
     """Like dict.update, except handling the nested dict called auth."""
     new_dict = copy.deepcopy(new_dict_source)
-    for (k, v) in new_dict.items():
+    for k, v in new_dict.items():
         if k == 'auth':
             if k in old_dict:
                 old_dict[k].update(v)
@@ -124,7 +132,7 @@ def _fix_argv(argv):
                 argv[index] = "=".join(split_args)
             # Save both for later so we can throw an error about dupes
             processed[new].add(orig)
-    overlap = []
+    overlap: ty.List[str] = []
     for new, old in processed.items():
         if len(old) > 1:
             overlap.extend(old)
@@ -133,26 +141,36 @@ def _fix_argv(argv):
             "The following options were given: '{options}' which contain"
             " duplicates except that one has _ and one has -. There is"
             " no sane way for us to know what you're doing. Remove the"
-            " duplicate option and try again".format(
-                options=','.join(overlap)))
+            " duplicate option and try again".format(options=','.join(overlap))
+        )
 
 
 class OpenStackConfig:
-
     # These two attribute are to allow os-client-config to plumb in its
     # local versions for backwards compat.
     # They should not be used by anyone else.
     _cloud_region_class = cloud_region.CloudRegion
     _defaults_module = defaults
 
-    def __init__(self, config_files=None, vendor_files=None,
-                 override_defaults=None, force_ipv4=None,
-                 envvar_prefix=None, secure_files=None,
-                 pw_func=None, session_constructor=None,
-                 app_name=None, app_version=None,
-                 load_yaml_config=True, load_envvars=True,
-                 statsd_host=None, statsd_port=None,
-                 statsd_prefix=None, influxdb_config=None):
+    def __init__(
+        self,
+        config_files=None,
+        vendor_files=None,
+        override_defaults=None,
+        force_ipv4=None,
+        envvar_prefix=None,
+        secure_files=None,
+        pw_func=None,
+        session_constructor=None,
+        app_name=None,
+        app_version=None,
+        load_yaml_config=True,
+        load_envvars=True,
+        statsd_host=None,
+        statsd_port=None,
+        statsd_prefix=None,
+        influxdb_config=None,
+    ):
         self.log = _log.setup_logging('openstack.config')
         self._session_constructor = session_constructor
         self._app_name = app_name
@@ -195,7 +213,8 @@ class OpenStackConfig:
         _, secure_config = self._load_secure_file()
         if secure_config:
             self.cloud_config = _util.merge_clouds(
-                self.cloud_config, secure_config)
+                self.cloud_config, secure_config
+            )
 
         if not self.cloud_config:
             self.cloud_config = {'clouds': {}}
@@ -216,14 +235,20 @@ class OpenStackConfig:
             # Get the backwards compat value
             prefer_ipv6 = get_boolean(
                 self._get_envvar(
-                    'OS_PREFER_IPV6', client_config.get(
-                        'prefer_ipv6', client_config.get(
-                            'prefer-ipv6', True))))
+                    'OS_PREFER_IPV6',
+                    client_config.get(
+                        'prefer_ipv6', client_config.get('prefer-ipv6', True)
+                    ),
+                )
+            )
             force_ipv4 = get_boolean(
                 self._get_envvar(
-                    'OS_FORCE_IPV4', client_config.get(
-                        'force_ipv4', client_config.get(
-                            'broken-ipv6', False))))
+                    'OS_FORCE_IPV4',
+                    client_config.get(
+                        'force_ipv4', client_config.get('broken-ipv6', False)
+                    ),
+                )
+            )
 
             self.force_ipv4 = force_ipv4
             if not prefer_ipv6:
@@ -238,8 +263,10 @@ class OpenStackConfig:
                 '"{0}" defines a cloud named "{1}", but'
                 ' OS_CLOUD_NAME is also set to "{1}". Please rename'
                 ' either your environment based cloud, or one of your'
-                ' file-based clouds.'.format(self.config_filename,
-                                             self.envvar_key))
+                ' file-based clouds.'.format(
+                    self.config_filename, self.envvar_key
+                )
+            )
 
         self.default_cloud = self._get_envvar('OS_CLOUD')
 
@@ -258,35 +285,37 @@ class OpenStackConfig:
                 # clouds.yaml.
                 # The next/iter thing is for python3 compat where dict.keys
                 # returns an iterator but in python2 it's a list.
-                self.default_cloud = next(iter(
-                    self.cloud_config['clouds'].keys()))
+                self.default_cloud = next(
+                    iter(self.cloud_config['clouds'].keys())
+                )
 
         # Finally, fall through and make a cloud that starts with defaults
         # because we need somewhere to put arguments, and there are neither
         # config files or env vars
         if not self.cloud_config['clouds']:
-            self.cloud_config = dict(
-                clouds=dict(defaults=dict(self.defaults)))
+            self.cloud_config = dict(clouds=dict(defaults=dict(self.defaults)))
             self.default_cloud = 'defaults'
 
         self._cache_auth = False
         self._cache_expiration_time = 0
         self._cache_path = CACHE_PATH
         self._cache_class = 'dogpile.cache.null'
-        self._cache_arguments = {}
-        self._cache_expirations = {}
+        self._cache_arguments: ty.Dict[str, ty.Any] = {}
+        self._cache_expirations: ty.Dict[str, int] = {}
         self._influxdb_config = {}
         if 'cache' in self.cloud_config:
             cache_settings = _util.normalize_keys(self.cloud_config['cache'])
 
             self._cache_auth = get_boolean(
-                cache_settings.get('auth', self._cache_auth))
+                cache_settings.get('auth', self._cache_auth)
+            )
 
             # expiration_time used to be 'max_age' but the dogpile setting
             # is expiration_time. Support max_age for backwards compat.
             self._cache_expiration_time = cache_settings.get(
-                'expiration_time', cache_settings.get(
-                    'max_age', self._cache_expiration_time))
+                'expiration_time',
+                cache_settings.get('max_age', self._cache_expiration_time),
+            )
 
             # If cache class is given, use that. If not, but if cache time
             # is given, default to memory. Otherwise, default to nothing.
@@ -294,14 +323,18 @@ class OpenStackConfig:
             if self._cache_expiration_time:
                 self._cache_class = 'dogpile.cache.memory'
             self._cache_class = self.cloud_config['cache'].get(
-                'class', self._cache_class)
+                'class', self._cache_class
+            )
 
             self._cache_path = os.path.expanduser(
-                cache_settings.get('path', self._cache_path))
+                cache_settings.get('path', self._cache_path)
+            )
             self._cache_arguments = cache_settings.get(
-                'arguments', self._cache_arguments)
+                'arguments', self._cache_arguments
+            )
             self._cache_expirations = cache_settings.get(
-                'expiration', self._cache_expirations)
+                'expiration', self._cache_expirations
+            )
 
         if load_yaml_config:
             metrics_config = self.cloud_config.get('metrics', {})
@@ -325,12 +358,21 @@ class OpenStackConfig:
                     use_udp = use_udp.lower() in ('true', 'yes', '1')
                 elif not isinstance(use_udp, bool):
                     use_udp = False
-                    self.log.warning('InfluxDB.use_udp value type is not '
-                                     'supported. Use one of '
-                                     '[true|false|yes|no|1|0]')
+                    self.log.warning(
+                        'InfluxDB.use_udp value type is not '
+                        'supported. Use one of '
+                        '[true|false|yes|no|1|0]'
+                    )
                 config['use_udp'] = use_udp
-            for key in ['host', 'port', 'username', 'password', 'database',
-                        'measurement', 'timeout']:
+            for key in [
+                'host',
+                'port',
+                'username',
+                'password',
+                'database',
+                'measurement',
+                'timeout',
+            ]:
                 if key in influxdb_config:
                     config[key] = influxdb_config[key]
             self._influxdb_config = config
@@ -356,20 +398,28 @@ class OpenStackConfig:
         if not envvar_prefix:
             # This makes the or below be OS_ or OS_ which is a no-op
             envvar_prefix = 'OS_'
-        environkeys = [k for k in os.environ.keys()
-                       if (k.startswith('OS_') or k.startswith(envvar_prefix))
-                       and not k.startswith('OS_TEST')  # infra CI var
-                       and not k.startswith('OS_STD')   # oslotest var
-                       and not k.startswith('OS_LOG')   # oslotest var
-                       ]
+        environkeys = [
+            k
+            for k in os.environ.keys()
+            if (k.startswith('OS_') or k.startswith(envvar_prefix))
+            and not k.startswith('OS_TEST')  # infra CI var
+            and not k.startswith('OS_STD')  # oslotest var
+            and not k.startswith('OS_LOG')  # oslotest var
+        ]
         for k in environkeys:
             newkey = k.split('_', 1)[-1].lower()
             ret[newkey] = os.environ[k]
         # If the only environ keys are selectors or behavior modification,
         # don't return anything
-        selectors = set([
-            'OS_CLOUD', 'OS_REGION_NAME',
-            'OS_CLIENT_CONFIG_FILE', 'OS_CLIENT_SECURE_FILE', 'OS_CLOUD_NAME'])
+        selectors = set(
+            [
+                'OS_CLOUD',
+                'OS_REGION_NAME',
+                'OS_CLIENT_CONFIG_FILE',
+                'OS_CLIENT_SECURE_FILE',
+                'OS_CLOUD_NAME',
+            ]
+        )
         if set(environkeys) - selectors:
             return ret
         return None
@@ -390,8 +440,8 @@ class OpenStackConfig:
         if not key:
             return defaults
         return _util.merge_clouds(
-            defaults,
-            _util.normalize_keys(self.cloud_config.get(key, {})))
+            defaults, _util.normalize_keys(self.cloud_config.get(key, {}))
+        )
 
     def _load_config_file(self):
         return self._load_yaml_json_file(self._config_files)
@@ -426,10 +476,12 @@ class OpenStackConfig:
         for region in regions:
             if isinstance(region, dict):
                 # i.e. must have name key, and only name,values keys
-                if 'name' not in region or \
-                   not {'name', 'values'} >= set(region):
+                if 'name' not in region or not {'name', 'values'} >= set(
+                    region
+                ):
                     raise exceptions.ConfigException(
-                        'Invalid region entry at: %s' % region)
+                        'Invalid region entry at: %s' % region
+                    )
                 if 'values' not in region:
                     region['values'] = {}
                 ret.append(copy.deepcopy(region))
@@ -457,14 +509,16 @@ class OpenStackConfig:
                 regions = config['region_name'].split(',')
             if len(regions) > 1:
                 warnings.warn(
-                    "Comma separated lists in region_name are deprecated."
-                    " Please use a yaml list in the regions"
-                    " parameter in {0} instead.".format(self.config_filename))
+                    f"Comma separated lists in region_name are deprecated. "
+                    f"Please use a yaml list in the regions "
+                    f"parameter in {self.config_filename} instead.",
+                    os_warnings.OpenStackDeprecationWarning,
+                )
             return self._expand_regions(regions)
         else:
             # crappit. we don't have a region defined.
-            new_cloud = dict()
-            our_cloud = self.cloud_config['clouds'].get(cloud, dict())
+            new_cloud: ty.Dict[str, ty.Any] = {}
+            our_cloud = self.cloud_config['clouds'].get(cloud, {})
             self._expand_vendor_profile(cloud, new_cloud, our_cloud)
             if 'regions' in new_cloud and new_cloud['regions']:
                 return self._expand_regions(new_cloud['regions'])
@@ -494,7 +548,9 @@ class OpenStackConfig:
             ' region names are case sensitive.'.format(
                 region_name=region_name,
                 region_list=','.join([r['name'] for r in regions]),
-                cloud=cloud))
+                cloud=cloud,
+            )
+        )
 
     def get_cloud_names(self):
         return self.cloud_config['clouds'].keys()
@@ -505,8 +561,8 @@ class OpenStackConfig:
         # Only validate cloud name if one was given
         if name and name not in self.cloud_config['clouds']:
             raise exceptions.ConfigException(
-                "Cloud {name} was not found.".format(
-                    name=name))
+                "Cloud {name} was not found.".format(name=name)
+            )
 
         our_cloud = self.cloud_config['clouds'].get(name, dict())
         if profile:
@@ -533,13 +589,18 @@ class OpenStackConfig:
             return
         if 'cloud' in our_cloud:
             warnings.warn(
-                "{0} uses the keyword 'cloud' to reference a known "
-                "vendor profile. This has been deprecated in favor of the "
-                "'profile' keyword.".format(self.config_filename))
+                f"{self.config_filename} uses the keyword 'cloud' to "
+                f"reference a known vendor profile. This has been deprecated "
+                f"in favor of the 'profile' keyword.",
+                os_warnings.OpenStackDeprecationWarning,
+            )
 
         vendor_filename, vendor_file = self._load_vendor_file()
-        if (vendor_file and 'public-clouds' in vendor_file
-                and profile_name in vendor_file['public-clouds']):
+        if (
+            vendor_file
+            and 'public-clouds' in vendor_file
+            and profile_name in vendor_file['public-clouds']
+        ):
             _auth_update(cloud, vendor_file['public-clouds'][profile_name])
         else:
             profile_data = vendors.get_profile(profile_name)
@@ -553,24 +614,32 @@ class OpenStackConfig:
                 message = profile_data.pop('message', '')
                 if status == 'deprecated':
                     warnings.warn(
-                        "{profile_name} is deprecated: {message}".format(
-                            profile_name=profile_name, message=message))
+                        f"{profile_name} is deprecated: {message}",
+                        os_warnings.OpenStackDeprecationWarning,
+                    )
                 elif status == 'shutdown':
                     raise exceptions.ConfigException(
                         "{profile_name} references a cloud that no longer"
                         " exists: {message}".format(
-                            profile_name=profile_name, message=message))
+                            profile_name=profile_name, message=message
+                        )
+                    )
                 _auth_update(cloud, profile_data)
             else:
                 # Can't find the requested vendor config, go about business
-                warnings.warn("Couldn't find the vendor profile '{0}', for"
-                              " the cloud '{1}'".format(profile_name,
-                                                        name))
+                warnings.warn(
+                    f"Couldn't find the vendor profile {profile_name} for "
+                    f"the cloud {name}",
+                    os_warnings.ConfigurationWarning,
+                )
 
     def _project_scoped(self, cloud):
-        return ('project_id' in cloud or 'project_name' in cloud
-                or 'project_id' in cloud['auth']
-                or 'project_name' in cloud['auth'])
+        return (
+            'project_id' in cloud
+            or 'project_name' in cloud
+            or 'project_id' in cloud['auth']
+            or 'project_name' in cloud['auth']
+        )
 
     def _validate_networks(self, networks, key):
         value = None
@@ -579,9 +648,9 @@ class OpenStackConfig:
                 raise exceptions.ConfigException(
                     "Duplicate network entries for {key}: {net1} and {net2}."
                     " Only one network can be flagged with {key}".format(
-                        key=key,
-                        net1=value['name'],
-                        net2=net['name']))
+                        key=key, net1=value['name'], net2=net['name']
+                    )
+                )
             if not value and net[key]:
                 value = net
 
@@ -594,7 +663,8 @@ class OpenStackConfig:
             name = net.get('name')
             if not name:
                 raise exceptions.ConfigException(
-                    'Entry in network list is missing required field "name".')
+                    'Entry in network list is missing required field "name".'
+                )
             network = dict(
                 name=name,
                 routes_externally=get_boolean(net.get('routes_externally')),
@@ -604,12 +674,12 @@ class OpenStackConfig:
             )
             # routes_ipv4_externally defaults to the value of routes_externally
             network['routes_ipv4_externally'] = get_boolean(
-                net.get(
-                    'routes_ipv4_externally', network['routes_externally']))
+                net.get('routes_ipv4_externally', network['routes_externally'])
+            )
             # routes_ipv6_externally defaults to the value of routes_externally
             network['routes_ipv6_externally'] = get_boolean(
-                net.get(
-                    'routes_ipv6_externally', network['routes_externally']))
+                net.get('routes_ipv6_externally', network['routes_externally'])
+            )
             networks.append(network)
 
         for key in ('external_network', 'internal_network'):
@@ -618,18 +688,23 @@ class OpenStackConfig:
                 raise exceptions.ConfigException(
                     "Both {key} and networks were specified in the config."
                     " Please remove {key} from the config and use the network"
-                    " list to configure network behavior.".format(key=key))
+                    " list to configure network behavior.".format(key=key)
+                )
             if key in cloud:
                 warnings.warn(
-                    "{key} is deprecated. Please replace with an entry in"
-                    " a dict inside of the networks list with name: {name}"
-                    " and routes_externally: {external}".format(
-                        key=key, name=cloud[key], external=external))
-                networks.append(dict(
-                    name=cloud[key],
-                    routes_externally=external,
-                    nat_destination=not external,
-                    default_interface=external))
+                    f"{key} is deprecated. Please replace with an entry in "
+                    f"a dict inside of the networks list with name: "
+                    f"{cloud[key]} and routes_externally: {external}",
+                    os_warnings.OpenStackDeprecationWarning,
+                )
+                networks.append(
+                    dict(
+                        name=cloud[key],
+                        routes_externally=external,
+                        nat_destination=not external,
+                        default_interface=external,
+                    )
+                )
 
         # Validate that we don't have duplicates
         self._validate_networks(networks, 'nat_destination')
@@ -667,7 +742,9 @@ class OpenStackConfig:
             'user_domain_name': ('user_domain_name', 'user-domain-name'),
             'project_domain_id': ('project_domain_id', 'project-domain-id'),
             'project_domain_name': (
-                'project_domain_name', 'project-domain-name'),
+                'project_domain_name',
+                'project-domain-name',
+            ),
             'token': ('auth-token', 'auth_token', 'token'),
         }
         if cloud.get('auth_type', None) == 'v2password':
@@ -675,23 +752,42 @@ class OpenStackConfig:
             # clouds. That's fine - we need to map settings in the opposite
             # direction
             mappings['tenant_id'] = (
-                'project_id', 'project-id', 'tenant_id', 'tenant-id')
+                'project_id',
+                'project-id',
+                'tenant_id',
+                'tenant-id',
+            )
             mappings['tenant_name'] = (
-                'project_name', 'project-name', 'tenant_name', 'tenant-name')
+                'project_name',
+                'project-name',
+                'tenant_name',
+                'tenant-name',
+            )
         else:
             mappings['project_id'] = (
-                'tenant_id', 'tenant-id', 'project_id', 'project-id')
+                'tenant_id',
+                'tenant-id',
+                'project_id',
+                'project-id',
+            )
             mappings['project_name'] = (
-                'tenant_name', 'tenant-name', 'project_name', 'project-name')
+                'tenant_name',
+                'tenant-name',
+                'project_name',
+                'project-name',
+            )
         for target_key, possible_values in mappings.items():
             target = None
             for key in possible_values:
-                if key in cloud:
-                    target = str(cloud[key])
-                    del cloud[key]
+                # Prefer values from the 'auth' section
+                # as they may contain cli or environment overrides.
+                # See story 2010784 for context.
                 if key in cloud['auth']:
                     target = str(cloud['auth'][key])
                     del cloud['auth'][key]
+                if key in cloud:
+                    target = str(cloud[key])
+                    del cloud[key]
             if target:
                 cloud['auth'][target_key] = target
         return cloud
@@ -746,7 +842,8 @@ class OpenStackConfig:
                 '--os-cloud',
                 metavar='<name>',
                 default=self._get_envvar('OS_CLOUD', None),
-                help='Named cloud to connect to')
+                help='Named cloud to connect to',
+            )
 
         # we need to peek to see if timeout was actually passed, since
         # the keystoneauth declaration of it has a default, which means
@@ -781,7 +878,8 @@ class OpenStackConfig:
 
         try:
             loading.register_auth_argparse_arguments(
-                parser, argv, default=default_auth_type)
+                parser, argv, default=default_auth_type
+            )
         except Exception:
             # Hidiing the keystoneauth exception because we're not actually
             # loading the auth plugin at this point, so the error message
@@ -792,7 +890,9 @@ class OpenStackConfig:
                 "An invalid auth-type was specified: {auth_type}."
                 " Valid choices are: {plugin_names}.".format(
                     auth_type=options.os_auth_type,
-                    plugin_names=",".join(plugin_names)))
+                    plugin_names=",".join(plugin_names),
+                )
+            )
 
         if service_keys:
             primary_service = service_keys[0]
@@ -800,15 +900,19 @@ class OpenStackConfig:
             primary_service = None
         loading.register_session_argparse_arguments(parser)
         adapter.register_adapter_argparse_arguments(
-            parser, service_type=primary_service)
+            parser, service_type=primary_service
+        )
         for service_key in service_keys:
             # legacy clients have un-prefixed api-version options
             parser.add_argument(
                 '--{service_key}-api-version'.format(
-                    service_key=service_key.replace('_', '-')),
-                help=argparse_mod.SUPPRESS)
+                    service_key=service_key.replace('_', '-')
+                ),
+                help=argparse_mod.SUPPRESS,
+            )
             adapter.register_service_adapter_argparse_arguments(
-                parser, service_type=service_key)
+                parser, service_type=service_key
+            )
 
         # Backwards compat options for legacy clients
         parser.add_argument('--http-timeout', help=argparse_mod.SUPPRESS)
@@ -836,7 +940,8 @@ class OpenStackConfig:
         service_timeout = None
         for key in cloud.keys():
             if key.endswith('timeout') and not (
-                    key == 'timeout' or key == 'api_timeout'):
+                key == 'timeout' or key == 'api_timeout'
+            ):
                 service_timeout = cloud[key]
             else:
                 new_cloud[key] = cloud[key]
@@ -850,15 +955,16 @@ class OpenStackConfig:
         return new_cloud
 
     def get_all(self):
-
         clouds = []
 
         for cloud in self.get_cloud_names():
             for region in self._get_regions(cloud):
                 if region:
-                    clouds.append(self.get_one(
-                        cloud, region_name=region['name']))
+                    clouds.append(
+                        self.get_one(cloud, region_name=region['name'])
+                    )
         return clouds
+
     # TODO(mordred) Backwards compat for OSC transition
     get_all_clouds = get_all
 
@@ -884,8 +990,8 @@ class OpenStackConfig:
 
         os_args = dict()
         new_args = dict()
-        for (key, val) in iter(args.items()):
-            if type(args[key]) == dict:
+        for key, val in iter(args.items()):
+            if type(args[key]) is dict:
                 # dive into the auth dict
                 new_args[key] = self._fix_args(args[key])
                 continue
@@ -903,8 +1009,9 @@ class OpenStackConfig:
         if opt_name in config:
             return config[opt_name]
         else:
-            deprecated = getattr(opt, 'deprecated', getattr(
-                opt, 'deprecated_opts', []))
+            deprecated = getattr(
+                opt, 'deprecated', getattr(opt, 'deprecated_opts', [])
+            )
             for d_opt in deprecated:
                 d_opt_name = d_opt.name.replace('-', '_')
                 if d_opt_name in config:
@@ -932,7 +1039,25 @@ class OpenStackConfig:
             # That it does not exist in keystoneauth is irrelvant- it not
             # doing what they want causes them sorrow.
             config['auth_type'] = 'admin_token'
-        return loading.get_plugin_loader(config['auth_type'])
+
+        loader = loading.get_plugin_loader(config['auth_type'])
+
+        # As the name would suggest, v3multifactor uses multiple factors for
+        # authentication. As a result, we need to register the configuration
+        # options for each required auth method. Normally, this is handled by
+        # the 'MultiFactor.load_from_options' method but there doesn't appear
+        # to be a way to "register" the auth methods without actually loading
+        # the plugin. As a result, if we encounter this auth type then we need
+        # to do this registration of extra options manually.
+        # FIXME(stephenfin): We need to provide a mechanism to extend the
+        # options in keystoneauth1.loading._plugins.identity.v3.MultiAuth
+        # without calling 'load_from_options'.
+        if config['auth_type'] == 'v3multifactor':
+            # We use '.get' since we can't be sure this key is set yet -
+            # validation happens later, in _validate_auth
+            loader._methods = config.get('auth_methods')
+
+        return loader
 
     def _validate_auth(self, config, loader):
         # May throw a keystoneauth1.exceptions.NoMatchingPlugin
@@ -1008,15 +1133,14 @@ class OpenStackConfig:
     def option_prompt(self, config, p_opt):
         """Prompt user for option that requires a value"""
         if (
-                getattr(p_opt, 'prompt', None) is not None
-                and p_opt.dest not in config['auth']
-                and self._pw_callback is not None
+            getattr(p_opt, 'prompt', None) is not None
+            and p_opt.dest not in config['auth']
+            and self._pw_callback is not None
         ):
             config['auth'][p_opt.dest] = self._pw_callback(p_opt.prompt)
         return config
 
     def _clean_up_after_ourselves(self, config, p_opt, winning_value):
-
         # Clean up after ourselves
         for opt in [p_opt.name] + [o.name for o in p_opt.deprecated]:
             opt = opt.replace('-', '_')
@@ -1027,8 +1151,7 @@ class OpenStackConfig:
             # Prefer the plugin configuration dest value if the value's key
             # is marked as depreciated.
             if p_opt.dest is None:
-                config['auth'][p_opt.name.replace('-', '_')] = (
-                    winning_value)
+                config['auth'][p_opt.name.replace('-', '_')] = winning_value
             else:
                 config['auth'][p_opt.dest] = winning_value
         return config
@@ -1037,9 +1160,11 @@ class OpenStackConfig:
         """Perform the set of magic argument fixups"""
 
         # Infer token plugin if a token was given
-        if (('auth' in config and 'token' in config['auth'])
-                or ('auth_token' in config and config['auth_token'])
-                or ('token' in config and config['token'])):
+        if (
+            ('auth' in config and 'token' in config['auth'])
+            or ('auth_token' in config and config['auth_token'])
+            or ('token' in config and config['token'])
+        ):
             config.setdefault('token', config.pop('auth_token', None))
 
         # Infer passcode if it was given separately
@@ -1065,17 +1190,22 @@ class OpenStackConfig:
                 if type(config[key]) is not bool:
                     config[key] = get_boolean(config[key])
 
+        for key in CSV_KEYS:
+            if key in config:
+                if isinstance(config[key], str):
+                    config[key] = config[key].split(',')
+
         # TODO(mordred): Special casing auth_url here. We should
         #                come back to this betterer later so that it's
         #                more generalized
         if 'auth' in config and 'auth_url' in config['auth']:
             config['auth']['auth_url'] = config['auth']['auth_url'].format(
-                **config)
+                **config
+            )
 
         return config
 
-    def get_one(
-            self, cloud=None, validate=True, argparse=None, **kwargs):
+    def get_one(self, cloud=None, validate=True, argparse=None, **kwargs):
         """Retrieve a single CloudRegion and merge additional options
 
         :param string cloud:
@@ -1119,7 +1249,7 @@ class OpenStackConfig:
 
         # Can't just do update, because None values take over
         for arg_list in region_args, args:
-            for (key, val) in iter(arg_list.items()):
+            for key, val in iter(arg_list.items()):
                 if val is not None:
                     if key == 'auth' and config[key] is not None:
                         config[key] = _auth_update(config[key], val)
@@ -1142,7 +1272,7 @@ class OpenStackConfig:
             auth_plugin = None
 
         # If any of the defaults reference other values, we need to expand
-        for (key, value) in config.items():
+        for key, value in config.items():
             if hasattr(value, 'format') and key not in FORMAT_EXCLUSIONS:
                 config[key] = value.format(**config)
 
@@ -1193,15 +1323,12 @@ class OpenStackConfig:
             statsd_prefix=statsd_prefix,
             influxdb_config=influxdb_config,
         )
+
     # TODO(mordred) Backwards compat for OSC transition
     get_one_cloud = get_one
 
     def get_one_cloud_osc(
-        self,
-        cloud=None,
-        validate=True,
-        argparse=None,
-        **kwargs
+        self, cloud=None, validate=True, argparse=None, **kwargs
     ):
         """Retrieve a single CloudRegion and merge additional options
 
@@ -1244,7 +1371,7 @@ class OpenStackConfig:
 
         # Can't just do update, because None values take over
         for arg_list in region_args, args:
-            for (key, val) in iter(arg_list.items()):
+            for key, val in iter(arg_list.items()):
                 if val is not None:
                     if key == 'auth' and config[key] is not None:
                         config[key] = _auth_update(config[key], val)
@@ -1266,7 +1393,7 @@ class OpenStackConfig:
             auth_plugin = None
 
         # If any of the defaults reference other values, we need to expand
-        for (key, value) in config.items():
+        for key, value in config.items():
             if hasattr(value, 'format') and key not in FORMAT_EXCLUSIONS:
                 config[key] = value.format(**config)
 
@@ -1335,10 +1462,10 @@ if __name__ == '__main__':
         if len(sys.argv) == 1:
             print_cloud = True
         elif len(sys.argv) == 3 and (
-                sys.argv[1] == cloud.name and sys.argv[2] == cloud.region):
+            sys.argv[1] == cloud.name and sys.argv[2] == cloud.region
+        ):
             print_cloud = True
-        elif len(sys.argv) == 2 and (
-                sys.argv[1] == cloud.name):
+        elif len(sys.argv) == 2 and (sys.argv[1] == cloud.name):
             print_cloud = True
 
         if print_cloud:
