@@ -14,6 +14,7 @@ import openstack.exceptions as exception
 from openstack.identity.v3 import (
     application_credential as _application_credential,
 )
+from openstack.identity.v3 import access_rule as _access_rule
 from openstack.identity.v3 import credential as _credential
 from openstack.identity.v3 import domain as _domain
 from openstack.identity.v3 import domain_config as _domain_config
@@ -59,6 +60,7 @@ from openstack import utils
 class Proxy(proxy.Proxy):
     _resource_registry = {
         "application_credential": _application_credential.ApplicationCredential,  # noqa: E501
+        "access_rule": _access_rule.AccessRule,
         "credential": _credential.Credential,
         "domain": _domain.Domain,
         "endpoint": _endpoint.Endpoint,
@@ -1169,52 +1171,52 @@ class Proxy(proxy.Proxy):
             )
 
         if domain:
-            domain = self._get_resource(_domain.Domain, domain)
+            domain_id = resource.Resource._get_id(domain)
             if group:
-                group = self._get_resource(_group.Group, group)
+                group_id = resource.Resource._get_id(group)
                 return self._list(
                     _role_domain_group_assignment.RoleDomainGroupAssignment,
-                    domain_id=domain.id,
-                    group_id=group.id,
+                    domain_id=domain_id,
+                    group_id=group_id,
                 )
             else:
-                user = self._get_resource(_user.User, user)
+                user_id = resource.Resource._get_id(user)
                 return self._list(
                     _role_domain_user_assignment.RoleDomainUserAssignment,
-                    domain_id=domain.id,
-                    user_id=user.id,
+                    domain_id=domain_id,
+                    user_id=user_id,
                 )
         elif project:
-            project = self._get_resource(_project.Project, project)
+            project_id = resource.Resource._get_id(project)
             if group:
-                group = self._get_resource(_group.Group, group)
+                group_id = resource.Resource._get_id(group)
                 return self._list(
                     _role_project_group_assignment.RoleProjectGroupAssignment,
-                    project_id=project.id,
-                    group_id=group.id,
+                    project_id=project_id,
+                    group_id=group_id,
                 )
             else:
-                user = self._get_resource(_user.User, user)
+                user_id = resource.Resource._get_id(user)
                 return self._list(
                     _role_project_user_assignment.RoleProjectUserAssignment,
-                    project_id=project.id,
-                    user_id=user.id,
+                    project_id=project_id,
+                    user_id=user_id,
                 )
         else:
-            system = self._get_resource(_project.System, system)
+            system_id = resource.Resource._get_id(system)
             if group:
-                group = self._get_resource(_group.Group, group)
+                group_id = resource.Resource._get_id(group)
                 return self._list(
                     _role_system_group_assignment.RoleSystemGroupAssignment,
-                    system_id=system.id,
-                    group_id=group.id,
+                    system_id=system_id,
+                    group_id=group_id,
                 )
             else:
-                user = self._get_resource(_user.User, user)
+                user_id = resource.Resource._get_id(user)
                 return self._list(
                     _role_system_user_assignment.RoleSystemUserAssignment,
-                    system_id=system.id,
-                    user_id=user.id,
+                    system_id=system_id,
+                    user_id=user_id,
                 )
 
     def role_assignments(self, **query):
@@ -2128,3 +2130,56 @@ class Proxy(proxy.Proxy):
         return self._update(
             _identity_provider.IdentityProvider, identity_provider, **attrs
         )
+
+    # ========== Access rules ==========
+
+    def access_rules(self, user, **query):
+        """Retrieve a generator of access rules
+
+        :param user: Either the ID of a user or a :class:`~.user.User`
+            instance.
+        :param kwargs query: Optional query parameters to be sent to
+            limit the resources being returned.
+
+        :returns: A generator of access rules instances.
+        :rtype: :class:`~openstack.identity.v3.access_rule.AccessRule`
+        """
+        user = self._get_resource(_user.User, user)
+        return self._list(_access_rule.AccessRule, user_id=user.id, **query)
+
+    def get_access_rule(self, user, access_rule):
+        """Get a single access rule
+
+        :param user: Either the ID of a user or a :class:`~.user.User`
+            instance.
+        :param access rule: The value can be the ID of an access rule or a
+            :class:`~.access_rule.AccessRule` instance.
+
+        :returns: One :class:`~.access_rule.AccessRule`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        user = self._get_resource(_user.User, user)
+        return self._get(_access_rule.AccessRule, access_rule, user_id=user.id)
+
+    def delete_access_rule(self, user, access_rule, ignore_missing=True):
+        """Delete an access rule
+
+        :param user: Either the ID of a user or a :class:`~.user.User`
+            instance.
+        :param access rule: The value can be either the ID of an
+            access rule or a :class:`~.access_rule.AccessRule` instance.
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the access rule does not exist. When set to ``True``, no exception
+            will be thrown when attempting to delete a nonexistent access rule.
+
+        :returns: ``None``
+        """
+        user = self._get_resource(_user.User, user)
+        self._delete(
+            _access_rule.AccessRule,
+            access_rule,
+            user_id=user.id,
+            ignore_missing=ignore_missing,
+        )
