@@ -16,7 +16,6 @@ from openstack.tests.functional.block_storage.v3 import base
 
 
 class TestBackup(base.BaseBlockStorageTest):
-
     def setUp(self):
         super(TestBackup, self).setUp()
 
@@ -29,38 +28,39 @@ class TestBackup(base.BaseBlockStorageTest):
         self.BACKUP_ID = None
 
         volume = self.user_cloud.block_storage.create_volume(
-            name=self.VOLUME_NAME,
-            size=1)
+            name=self.VOLUME_NAME, size=1
+        )
         self.user_cloud.block_storage.wait_for_status(
             volume,
             status='available',
             failures=['error'],
             interval=5,
-            wait=self._wait_for_timeout)
+            wait=self._wait_for_timeout,
+        )
         assert isinstance(volume, _volume.Volume)
         self.VOLUME_ID = volume.id
 
         backup = self.user_cloud.block_storage.create_backup(
-            name=self.BACKUP_NAME,
-            volume_id=volume.id,
-            is_incremental=False)
+            name=self.BACKUP_NAME, volume_id=volume.id, is_incremental=False
+        )
         self.user_cloud.block_storage.wait_for_status(
             backup,
             status='available',
             failures=['error'],
             interval=5,
-            wait=self._wait_for_timeout)
+            wait=self._wait_for_timeout,
+        )
         assert isinstance(backup, _backup.Backup)
         self.assertEqual(self.BACKUP_NAME, backup.name)
         self.BACKUP_ID = backup.id
 
     def tearDown(self):
         sot = self.user_cloud.block_storage.delete_backup(
-            self.BACKUP_ID,
-            ignore_missing=False)
+            self.BACKUP_ID, ignore_missing=False
+        )
         sot = self.user_cloud.block_storage.delete_volume(
-            self.VOLUME_ID,
-            ignore_missing=False)
+            self.VOLUME_ID, ignore_missing=False
+        )
         self.assertIsNone(sot)
         super(TestBackup, self).tearDown()
 
@@ -73,31 +73,34 @@ class TestBackup(base.BaseBlockStorageTest):
         metadata_backup = self.user_cloud.block_storage.create_backup(
             name=self.getUniqueString(),
             volume_id=self.VOLUME_ID,
-            metadata=dict(foo="bar"))
+            metadata=dict(foo="bar"),
+        )
         self.user_cloud.block_storage.wait_for_status(
             metadata_backup,
             status='available',
             failures=['error'],
             interval=5,
-            wait=self._wait_for_timeout)
+            wait=self._wait_for_timeout,
+        )
         self.user_cloud.block_storage.delete_backup(
-            metadata_backup.id,
-            ignore_missing=False)
+            metadata_backup.id, ignore_missing=False
+        )
 
     def test_create_incremental(self):
         incremental_backup = self.user_cloud.block_storage.create_backup(
             name=self.getUniqueString(),
             volume_id=self.VOLUME_ID,
-            is_incremental=True)
+            is_incremental=True,
+        )
         self.user_cloud.block_storage.wait_for_status(
             incremental_backup,
             status='available',
             failures=['error'],
             interval=5,
-            wait=self._wait_for_timeout)
+            wait=self._wait_for_timeout,
+        )
         self.assertEqual(True, incremental_backup.is_incremental)
         self.user_cloud.block_storage.delete_backup(
-            incremental_backup.id,
-            ignore_missing=False)
-        self.user_cloud.block_storage.wait_for_delete(
-            incremental_backup)
+            incremental_backup.id, ignore_missing=False
+        )
+        self.user_cloud.block_storage.wait_for_delete(incremental_backup)
