@@ -34,8 +34,7 @@ SNAPSHOT = {
 
 DETAILS = {
     "os-extended-snapshot-attributes:progress": "100%",
-    "os-extended-snapshot-attributes:project_id":
-        "0c2eba2c5af04d3f9e9d0d410b371fde"
+    "os-extended-snapshot-attributes:project_id": "0c2eba2c5af04d3f9e9d0d410b371fde",  # noqa: E501
 }
 
 DETAILED_SNAPSHOT = SNAPSHOT.copy()
@@ -43,7 +42,6 @@ DETAILED_SNAPSHOT.update(**DETAILS)
 
 
 class TestSnapshot(base.TestCase):
-
     def test_basic(self):
         sot = snapshot.Snapshot(SNAPSHOT)
         self.assertEqual("snapshot", sot.resource_key)
@@ -55,13 +53,17 @@ class TestSnapshot(base.TestCase):
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
-        self.assertDictEqual({"name": "name",
-                              "status": "status",
-                              "all_projects": "all_tenants",
-                              "volume_id": "volume_id",
-                              "limit": "limit",
-                              "marker": "marker"},
-                             sot._query_mapping._mapping)
+        self.assertDictEqual(
+            {
+                "name": "name",
+                "status": "status",
+                "all_projects": "all_tenants",
+                "volume_id": "volume_id",
+                "limit": "limit",
+                "marker": "marker",
+            },
+            sot._query_mapping._mapping,
+        )
 
     def test_create_basic(self):
         sot = snapshot.Snapshot(**SNAPSHOT)
@@ -77,7 +79,6 @@ class TestSnapshot(base.TestCase):
 
 
 class TestSnapshotActions(base.TestCase):
-
     def setUp(self):
         super(TestSnapshotActions, self).setUp()
         self.resp = mock.Mock()
@@ -99,4 +100,5 @@ class TestSnapshotActions(base.TestCase):
         url = 'snapshots/%s/action' % FAKE_ID
         body = {'os-reset_status': {'status': 'new_status'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
