@@ -20,11 +20,13 @@ from openstack.tests.unit import base
 FAKE_ID = "6685584b-1eac-4da6-b5c3-555430cf68ff"
 IMAGE_METADATA = {
     'container_format': 'bare',
-    'min_ram': '64', 'disk_format': u'qcow2',
+    'min_ram': '64',
+    'disk_format': u'qcow2',
     'image_name': 'TestVM',
     'image_id': '625d4f2c-cf67-4af3-afb6-c7220f766947',
     'checksum': '64d7c1cd2b6f60c92c14662941cb7913',
-    'min_disk': '0', u'size': '13167616'
+    'min_disk': '0',
+    u'size': '13167616',
 }
 
 VOLUME = {
@@ -57,14 +59,13 @@ VOLUME = {
     "OS-SCH-HNT:scheduler_hints": {
         "same_host": [
             "a0cf03a5-d921-4877-bb5c-86d26cf818e1",
-            "8c19174f-4220-44f0-824a-cd1eeef10287"
+            "8c19174f-4220-44f0-824a-cd1eeef10287",
         ]
-    }
+    },
 }
 
 
 class TestVolume(base.TestCase):
-
     def test_basic(self):
         sot = volume.Volume(VOLUME)
         self.assertEqual("volume", sot.resource_key)
@@ -76,13 +77,17 @@ class TestVolume(base.TestCase):
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
-        self.assertDictEqual({"name": "name",
-                              "status": "status",
-                              "all_projects": "all_tenants",
-                              "project_id": "project_id",
-                              "limit": "limit",
-                              "marker": "marker"},
-                             sot._query_mapping._mapping)
+        self.assertDictEqual(
+            {
+                "name": "name",
+                "status": "status",
+                "all_projects": "all_tenants",
+                "project_id": "project_id",
+                "limit": "limit",
+                "marker": "marker",
+            },
+            sot._query_mapping._mapping,
+        )
 
     def test_create(self):
         sot = volume.Volume(**VOLUME)
@@ -98,33 +103,40 @@ class TestVolume(base.TestCase):
         self.assertEqual(VOLUME["snapshot_id"], sot.snapshot_id)
         self.assertEqual(VOLUME["source_volid"], sot.source_volume_id)
         self.assertEqual(VOLUME["metadata"], sot.metadata)
-        self.assertEqual(VOLUME["volume_image_metadata"],
-                         sot.volume_image_metadata)
+        self.assertEqual(
+            VOLUME["volume_image_metadata"], sot.volume_image_metadata
+        )
         self.assertEqual(VOLUME["size"], sot.size)
         self.assertEqual(VOLUME["imageRef"], sot.image_id)
         self.assertEqual(VOLUME["os-vol-host-attr:host"], sot.host)
-        self.assertEqual(VOLUME["os-vol-tenant-attr:tenant_id"],
-                         sot.project_id)
-        self.assertEqual(VOLUME["os-vol-mig-status-attr:migstat"],
-                         sot.migration_status)
-        self.assertEqual(VOLUME["os-vol-mig-status-attr:name_id"],
-                         sot.migration_id)
-        self.assertEqual(VOLUME["replication_status"],
-                         sot.replication_status)
+        self.assertEqual(
+            VOLUME["os-vol-tenant-attr:tenant_id"], sot.project_id
+        )
+        self.assertEqual(
+            VOLUME["os-vol-mig-status-attr:migstat"], sot.migration_status
+        )
+        self.assertEqual(
+            VOLUME["os-vol-mig-status-attr:name_id"], sot.migration_id
+        )
+        self.assertEqual(VOLUME["replication_status"], sot.replication_status)
         self.assertEqual(
             VOLUME["os-volume-replication:extended_status"],
-            sot.extended_replication_status)
-        self.assertEqual(VOLUME["consistencygroup_id"],
-                         sot.consistency_group_id)
-        self.assertEqual(VOLUME["os-volume-replication:driver_data"],
-                         sot.replication_driver_data)
-        self.assertDictEqual(VOLUME["OS-SCH-HNT:scheduler_hints"],
-                             sot.scheduler_hints)
+            sot.extended_replication_status,
+        )
+        self.assertEqual(
+            VOLUME["consistencygroup_id"], sot.consistency_group_id
+        )
+        self.assertEqual(
+            VOLUME["os-volume-replication:driver_data"],
+            sot.replication_driver_data,
+        )
+        self.assertDictEqual(
+            VOLUME["OS-SCH-HNT:scheduler_hints"], sot.scheduler_hints
+        )
         self.assertFalse(sot.is_encrypted)
 
 
 class TestVolumeActions(TestVolume):
-
     def setUp(self):
         super(TestVolumeActions, self).setUp()
         self.resp = mock.Mock()
@@ -144,7 +156,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {"os-extend": {"new_size": "20"}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_set_volume_bootable(self):
         sot = volume.Volume(**VOLUME)
@@ -154,7 +167,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-set_bootable': {'bootable': True}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_set_volume_bootable_false(self):
         sot = volume.Volume(**VOLUME)
@@ -164,7 +178,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-set_bootable': {'bootable': False}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_reset_status(self):
         sot = volume.Volume(**VOLUME)
@@ -172,10 +187,16 @@ class TestVolumeActions(TestVolume):
         self.assertIsNone(sot.reset_status(self.sess, '1', '2', '3'))
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-reset_status': {'status': '1', 'attach_status': '2',
-                                    'migration_status': '3'}}
+        body = {
+            'os-reset_status': {
+                'status': '1',
+                'attach_status': '2',
+                'migration_status': '3',
+            }
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_attach_instance(self):
         sot = volume.Volume(**VOLUME)
@@ -185,7 +206,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-attach': {'mountpoint': '1', 'instance_uuid': '2'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_detach(self):
         sot = volume.Volume(**VOLUME)
@@ -195,18 +217,19 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-detach': {'attachment_id': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_detach_force(self):
         sot = volume.Volume(**VOLUME)
 
-        self.assertIsNone(
-            sot.detach(self.sess, '1', force=True))
+        self.assertIsNone(sot.detach(self.sess, '1', force=True))
 
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-force_detach': {'attachment_id': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_unmanage(self):
         sot = volume.Volume(**VOLUME)
@@ -214,9 +237,10 @@ class TestVolumeActions(TestVolume):
         self.assertIsNone(sot.unmanage(self.sess))
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-unmanage': {}}
+        body = {'os-unmanage': None}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_retype(self):
         sot = volume.Volume(**VOLUME)
@@ -226,7 +250,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-retype': {'new_type': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_retype_mp(self):
         sot = volume.Volume(**VOLUME)
@@ -236,7 +261,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-retype': {'new_type': '1', 'migration_policy': '2'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_migrate(self):
         sot = volume.Volume(**VOLUME)
@@ -246,19 +272,29 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-migrate_volume': {'host': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_migrate_flags(self):
         sot = volume.Volume(**VOLUME)
 
-        self.assertIsNone(sot.migrate(self.sess, host='1',
-                                      force_host_copy=True, lock_volume=True))
+        self.assertIsNone(
+            sot.migrate(
+                self.sess, host='1', force_host_copy=True, lock_volume=True
+            )
+        )
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-migrate_volume': {'host': '1', 'force_host_copy': True,
-                                      'lock_volume': True}}
+        body = {
+            'os-migrate_volume': {
+                'host': '1',
+                'force_host_copy': True,
+                'lock_volume': True,
+            }
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_complete_migration(self):
         sot = volume.Volume(**VOLUME)
@@ -266,22 +302,27 @@ class TestVolumeActions(TestVolume):
         self.assertIsNone(sot.complete_migration(self.sess, new_volume_id='1'))
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-migrate_volume_completion': {'new_volume': '1', 'error':
-                                                 False}}
+        body = {
+            'os-migrate_volume_completion': {'new_volume': '1', 'error': False}
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_complete_migration_error(self):
         sot = volume.Volume(**VOLUME)
 
-        self.assertIsNone(sot.complete_migration(
-            self.sess, new_volume_id='1', error=True))
+        self.assertIsNone(
+            sot.complete_migration(self.sess, new_volume_id='1', error=True)
+        )
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-migrate_volume_completion': {'new_volume': '1', 'error':
-                                                 True}}
+        body = {
+            'os-migrate_volume_completion': {'new_volume': '1', 'error': True}
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_force_delete(self):
         sot = volume.Volume(**VOLUME)
@@ -289,6 +330,7 @@ class TestVolumeActions(TestVolume):
         self.assertIsNone(sot.force_delete(self.sess))
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-force_delete': {}}
+        body = {'os-force_delete': None}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
