@@ -11,16 +11,130 @@
 # limitations under the License.
 
 import copy
+from unittest import mock
 
 import testtools
 
-import openstack
-import openstack.cloud
+from openstack import exceptions
 from openstack.network.v2 import network as _network
 from openstack.tests.unit import base
 
 
-class TestNetwork(base.TestCase):
+class TestNeutronExtensions(base.TestCase):
+    def test__neutron_extensions(self):
+        body = [
+            {
+                "updated": "2014-06-1T10:00:00-00:00",
+                "name": "Distributed Virtual Router",
+                "links": [],
+                "alias": "dvr",
+                "description": "Enables configuration of Distributed Virtual Routers.",  # noqa: E501
+            },
+            {
+                "updated": "2013-07-23T10:00:00-00:00",
+                "name": "Allowed Address Pairs",
+                "links": [],
+                "alias": "allowed-address-pairs",
+                "description": "Provides allowed address pairs",
+            },
+        ]
+        self.register_uris(
+            [
+                dict(
+                    method='GET',
+                    uri=self.get_mock_url(
+                        'network', 'public', append=['v2.0', 'extensions']
+                    ),
+                    json=dict(extensions=body),
+                )
+            ]
+        )
+        extensions = self.cloud._neutron_extensions()
+        self.assertEqual(set(['dvr', 'allowed-address-pairs']), extensions)
+
+        self.assert_calls()
+
+    def test__neutron_extensions_fails(self):
+        self.register_uris(
+            [
+                dict(
+                    method='GET',
+                    uri=self.get_mock_url(
+                        'network', 'public', append=['v2.0', 'extensions']
+                    ),
+                    status_code=404,
+                )
+            ]
+        )
+        with testtools.ExpectedException(exceptions.ResourceNotFound):
+            self.cloud._neutron_extensions()
+
+        self.assert_calls()
+
+    def test__has_neutron_extension(self):
+        body = [
+            {
+                "updated": "2014-06-1T10:00:00-00:00",
+                "name": "Distributed Virtual Router",
+                "links": [],
+                "alias": "dvr",
+                "description": "Enables configuration of Distributed Virtual Routers.",  # noqa: E501
+            },
+            {
+                "updated": "2013-07-23T10:00:00-00:00",
+                "name": "Allowed Address Pairs",
+                "links": [],
+                "alias": "allowed-address-pairs",
+                "description": "Provides allowed address pairs",
+            },
+        ]
+        self.register_uris(
+            [
+                dict(
+                    method='GET',
+                    uri=self.get_mock_url(
+                        'network', 'public', append=['v2.0', 'extensions']
+                    ),
+                    json=dict(extensions=body),
+                )
+            ]
+        )
+        self.assertTrue(self.cloud._has_neutron_extension('dvr'))
+        self.assert_calls()
+
+    def test__has_neutron_extension_missing(self):
+        body = [
+            {
+                "updated": "2014-06-1T10:00:00-00:00",
+                "name": "Distributed Virtual Router",
+                "links": [],
+                "alias": "dvr",
+                "description": "Enables configuration of Distributed Virtual Routers.",  # noqa: E501
+            },
+            {
+                "updated": "2013-07-23T10:00:00-00:00",
+                "name": "Allowed Address Pairs",
+                "links": [],
+                "alias": "allowed-address-pairs",
+                "description": "Provides allowed address pairs",
+            },
+        ]
+        self.register_uris(
+            [
+                dict(
+                    method='GET',
+                    uri=self.get_mock_url(
+                        'network', 'public', append=['v2.0', 'extensions']
+                    ),
+                    json=dict(extensions=body),
+                )
+            ]
+        )
+        self.assertFalse(self.cloud._has_neutron_extension('invalid'))
+        self.assert_calls()
+
+
+class TestNetworks(base.TestCase):
     mock_new_network_rep = {
         'provider:physical_network': None,
         'ipv6_address_scope': None,
@@ -109,6 +223,12 @@ class TestNetwork(base.TestCase):
         self.cloud.list_networks(filters={'name': 'test'})
         self.assert_calls()
 
+    def test_list_networks_neutron_not_found(self):
+        self.use_nothing()
+        self.cloud.has_service = mock.Mock(return_value=False)
+        self.assertEqual([], self.cloud.list_networks())
+        self.assert_calls()
+
     def test_create_network(self):
         self.register_uris(
             [
@@ -346,7 +466,7 @@ class TestNetwork(base.TestCase):
     def test_create_network_wrong_availability_zone_hints_type(self):
         azh_opts = "invalid"
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'availability_zone_hints' must be a list",
         ):
             self.cloud.create_network(
@@ -356,7 +476,7 @@ class TestNetwork(base.TestCase):
     def test_create_network_provider_wrong_type(self):
         provider_opts = "invalid"
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'provider' must be a dict",
         ):
             self.cloud.create_network("netname", provider=provider_opts)
@@ -421,14 +541,14 @@ class TestNetwork(base.TestCase):
 
     def test_create_network_with_wrong_mtu_size(self):
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'mtu_size' must be greater than 67.",
         ):
             self.cloud.create_network("netname", mtu_size=42)
 
     def test_create_network_with_wrong_mtu_type(self):
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'mtu_size' must be an integer.",
         ):
             self.cloud.create_network("netname", mtu_size="fourty_two")
@@ -536,7 +656,7 @@ class TestNetwork(base.TestCase):
             ]
         )
         self.assertRaises(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             self.cloud.delete_network,
             network_name,
         )
